Slackware This Forum is for the discussion of Slackware Linux.
|
| Notices |
Welcome to LinuxQuestions.org, a friendly and active Linux Community.
You are currently viewing LQ as a guest. By joining our community you will have the ability to post topics, receive our newsletter, use the advanced search, subscribe to threads and access many other special features. Registration is quick, simple and absolutely free. Join our community today!
Note that registered members see fewer ads, and ContentLink is completely disabled once you log in.
Are you new to LinuxQuestions.org? Visit the following links:
Site Howto |
Site FAQ |
Sitemap |
Register Now
If you have any problems with the registration process or your account login, please contact us. If you need to reset your password, click here.
Having a problem logging in? Please visit this page to clear all LQ-related cookies.
 |
GNU/Linux Basic Guide
This 255-page guide will provide you with the keys to understand the philosophy of free software, teach you how to use and handle it, and give you the tools required to move easily in the world of GNU/Linux. Many users and administrators will be taking their first steps with this GNU/Linux Basic guide and it will show you how to approach and solve the problems you encounter.
Click Here to receive this Complete Guide absolutely free. |
|
 |
|
01-21-2012, 12:33 AM
|
#91
|
|
Member
Registered: Jan 2006
Distribution: Slackware
Posts: 457
Rep:
|
Quote:
Originally Posted by Old_Fogie
While the kernel in slackware 13.37 does support the processors and video at a basic level of functionality.
|
Honestly Old Fogie, it is difficult to understand what you are trying to say when you speak in incomplete sentences. The reconstructed Proto Indo-European language is the putative parent of many language families that enjoy widespread use today, including English. But despite the fact that there are more than 3 billion native speakers, in none of those languages could such a fragment be construed as a sentence.
|
|
|
|
|
Click here to see the post LQ members have rated as the most helpful post in this thread.
|
01-21-2012, 03:06 AM
|
#92
|
|
Senior Member
Registered: May 2008
Posts: 2,876
|
People who start a sentence with a conjunction shouldn't criticise the grammar of others.
|
|
|
|
01-21-2012, 04:03 AM
|
#93
|
|
LQ 5k Club
Registered: Jan 2006
Location: Oldham, Lancs, England
Distribution: Laptop: Slackware 14.0 // Desktop: Slackware64 14.0 // Netbook: Slackware 14.0
Posts: 6,196
|
But they do. And it's annoying. 
|
|
|
|
01-21-2012, 04:54 AM
|
#94
|
|
Member
Registered: May 2009
Posts: 198
Rep:
|
I am using 3.0.x for quite a long. 3.0.17 seems to finally become stable enough for everyday use and is a long-term supported branch.
Recently had need to use a bluetooth mouse. I use Alien's latest KDE. But for some reason it simply doesn't work. Tried to fix it, but found that it requires udev update. udev require upgrading to kmod (instead of module-tools) and util-linux update.
kmod replaces all the module tools like modprobe, lsmod and etc with one tool - kmod. simple symlinking modprobe, lsmod and etc to kmod seems to work. kmod-4 in general looks good.
Tried to build that myself, but new udev requires /dev to be mounted as devtmpfs and /run as tmpfs. Looks like I managed that far, but while loading radeon module it couldn't find firmware, while it is still there. So I stuck at firmware loading. Probably need some more time.
PS it seems too much for myself, just to enable bluetooth mose  )).
|
|
|
|
01-21-2012, 04:57 AM
|
#95
|
|
Member
Registered: Sep 2009
Location: Yorks. W.R. 167397
Distribution: Slackware 13.37
Posts: 171
Rep: 
|
and. 5. "That it is a solecism to begin a sentence with and is a faintly lingering superstition. The OED gives examples ranging from the 10th to the 19th c.; the Bible is full of them."
but. 6. "for the superstition about beginning a sentence with but or and see AND 5."
-- Fowler
|
|
|
1 members found this post helpful.
|
01-21-2012, 05:06 AM
|
#96
|
|
LQ 5k Club
Registered: Jan 2006
Location: Oldham, Lancs, England
Distribution: Laptop: Slackware 14.0 // Desktop: Slackware64 14.0 // Netbook: Slackware 14.0
Posts: 6,196
|
Quote:
|
And "Bob" saith: Let those who criticise another's grammar be cast into everlasting Slacklessness.
|
--The Gospel According To St brianL
|
|
|
|
01-21-2012, 05:14 AM
|
#97
|
|
Member
Registered: Sep 2009
Location: Yorks. W.R. 167397
Distribution: Slackware 13.37
Posts: 171
Rep: 
|
Quote:
|
And "Bob" saith: Let those who criticise another's grammar be cast into everlasting Slacklessness.
|
Well in that case, thank Bob (pbuh) that gcc confines itself to merely criticising syntax.
(Yes, that was indeed a split infinitive.)
|
|
|
|
01-21-2012, 05:53 AM
|
#98
|
|
Senior Member
Registered: May 2008
Posts: 2,876
|
Quote:
Originally Posted by 55020
and. 5. "That it is a solecism to begin a sentence with and is a faintly lingering superstition. The OED gives examples ranging from the 10th to the 19th c.; the Bible is full of them."
but. 6. "for the superstition about beginning a sentence with but or and see AND 5."
-- Fowler
|
That just shows that getting it wrong isn't anything new.
Joking aside, I don't care how people write... Within reason.
|
|
|
|
01-21-2012, 06:09 AM
|
#99
|
|
Senior Member
Registered: May 2008
Posts: 2,876
|
Quote:
Originally Posted by dolphin77
Tried to build that myself, but new udev requires /dev to be mounted as devtmpfs and /run as tmpfs.
|
Actually, devtmpfs should already be being used for /dev on 13.37. It just doesn't show on the output of df/mount because it doesn't get added to /etc/mtab. I sent a note with a couple of patches to Pat back in December 2010 for this, but he decided that it was better to leave the mount hidden from the user. I didn't really agree with his point, but it's his distro.
On the off-chance anyone is interested:
Code:
--- orig/etc/rc.d/rc.6 2010-12-28 15:42:38.994995899 +0000
+++ local/etc/rc.d/rc.6 2010-12-28 15:48:50.909000077 +0000
@@ -187,7 +187,7 @@
/bin/sync
echo "Unmounting local file systems."
-/bin/umount -v -a -t no,proc,sysfs
+/bin/umount -v -a -t no,proc,sysfs,devtmpfs
echo "Remounting root filesystem read-only."
/bin/mount -v -n -o remount,ro /
|
|
|
|
01-21-2012, 06:29 AM
|
#100
|
|
Member
Registered: Aug 2009
Location: London North West
Distribution: x86_64 Slack 13.37 current : +others
Posts: 459
Rep:
|
Of course you can use the Slackware string in your windo$e Firefox to show the Slackware icon as you can see in this post I am on my XP and its showing Slackware. !
|
|
|
|
01-21-2012, 07:35 AM
|
#101
|
|
LQ 5k Club
Registered: Jan 2006
Location: Oldham, Lancs, England
Distribution: Laptop: Slackware 14.0 // Desktop: Slackware64 14.0 // Netbook: Slackware 14.0
Posts: 6,196
|
Quote:
Originally Posted by hughetorrance
Of course you can use the Slackware string in your windo$e Firefox to show the Slackware icon as you can see in this post I am on my XP and its showing Slackware. !
|
No, I can't, because I got rid of my XP Pro yesterday. So I'm completely Windowless now...whoooooooopeeeeeeeee!!!! 
|
|
|
|
01-21-2012, 08:50 AM
|
#102
|
|
Member
Registered: Oct 2006
Location: Cp6uja
Distribution: Slackware and Porteus
Posts: 645
Rep:
|
Quote:
Originally Posted by 55020
and. 5. "That it is a solecism to begin a sentence with and is a faintly lingering superstition. The OED gives examples ranging from the 10th to the 19th c.; the Bible is full of them."
but. 6. "for the superstition about beginning a sentence with but or and see AND 5."
-- Fowler
|
Woke up this morning and read the late posts:
guess what?
21st century brought us "R2D2"s that wll vague flame-wars for us!
buyers get Yours one now! flame warfare completely effortless!

And GazL
Quote:
|
Joking aside, I don't care how people write... Within reason.
|
I would never Joke about how people care writing...

|
|
|
|
01-21-2012, 08:54 AM
|
#103
|
|
Guru
Registered: Oct 2005
Location: $RANDOM
Distribution: slackware64
Posts: 12,706
|
|
|
|
1 members found this post helpful.
|
01-21-2012, 09:38 AM
|
#104
|
|
LQ Newbie
Registered: Jul 2011
Posts: 21
Rep: 
|
Quote:
Originally Posted by Darth Vader
I feel a strong smell of Linux-PAM, from Patrick's kitchen ...
Unfortunately, Linux-PAM boil hard, so we have to wait. 
|
I smell the same thing too, since the latest version of util-linux drops non-PAM support ^^
Quote:
Originally Posted by gargamel
Serious:
My guess is, that Pat and the crew are watching and waiting for some current developments to settle. One question could be, if the next release will still have to include HAL, or if it is possible to get it out without it.
|
I've gotten rid of HAL since Slackware 13.2 and been happily using udisks and upower ever since. So it's definitely
possible.
My take on the future of Slackware :
Thanks to the efforts of RedHat and Lennart, the Linux userland is becoming more and more coherent and integrated day by day. The basic components are therefore becoming more and more dependent on each other and that means that it's going to get increasingly difficult not to standardize if you want to stay up to date. So I expect that either the next version of Slackware or the one after that (they might resist for a while) will see a lot of changes. Or that they will just quit altogether because they won't be able to continue with their conservative policies.
|
|
|
|
01-21-2012, 09:58 AM
|
#105
|
|
Guru
Registered: Oct 2005
Location: $RANDOM
Distribution: slackware64
Posts: 12,706
|
Quote:
Originally Posted by KnutBluetooth
My take on the future of Slackware :
Thanks to the efforts of RedHat and Lennart, the Linux userland is becoming more and more coherent and integrated day by day. The basic components are therefore becoming more and more dependent on each other and that means that it's going to get increasingly difficult not to standardize if you want to stay up to date. So I expect that either the next version of Slackware or the one after that (they might resist for a while) will see a lot of changes. Or that they will just quit altogether because they won't be able to continue with their conservative policies.
|
Absolute nonsense.
Just because the devs of a few utilities decide to drop support doesn't mean the end of Slackware. That is extreme extrapolation and very unlikely. Someone can fork the old code anytime.
I do not care at all for a "standardized" Linux, because that will be the end of it. Linux is about choice and about freedom, and I don't agree with RedHat or other companies coming with with some standard that they think everyone should use. I am free to use whatever I want, and if someone drops support for something, I'll just use something else.
PAM complicates things a lot, so I'm not sure how this is being dealt with, but I am sure that Pat V. and the team will make the right choice.
For sure it will NOT be the end of Slackware. Where do you get this stuff ?
|
|
|
|
| Thread Tools |
Search this Thread |
|
|
|
Posting Rules
|
You may not post new threads
You may not post replies
You may not post attachments
You may not edit your posts
HTML code is Off
|
|
|
All times are GMT -5. The time now is 10:21 PM.
|
|
LinuxQuestions.org is looking for people interested in writing
Editorials, Articles, Reviews, and more. If you'd like to contribute
content, let us know.
|
Latest Threads
LQ News
|
|
--- orig/etc/rc.d/rc.S 2010-12-28 14:56:44.527422281 +0000
+++ local/etc/rc.d/rc.S 2010-12-28 15:16:21.060424998 +0000
@@ -245,14 +245,19 @@
# but does prevent a small bug with /etc/mtab.
/bin/grep ' / ' /proc/mounts | grep -v "^rootfs" > /etc/mtab
# Fix /etc/mtab to list sys and proc if they were not yet entered in
# /etc/mtab because / was still mounted read-only:
if [ -d /proc/sys ]; then
/sbin/mount -f proc /proc -t proc
fi
if [ -d /sys/bus ]; then
/sbin/mount -f sysfs /sys -t sysfs
fi
+if [ -f /proc/mounts ]; then
+ if grep -wq "^devtmpfs" /proc/mounts ; then
+ /sbin/mount -f devtmpfs /dev -t devtmpfs
+ fi
+fi
# Configure ISA Plug-and-Play devices:
if [ -r /etc/isapnp.conf ]; then
@@ -245,14 +245,19 @@
# but does prevent a small bug with /etc/mtab.
/bin/grep ' / ' /proc/mounts | grep -v "^rootfs" > /etc/mtab
-# Fix /etc/mtab to list sys and proc if they were not yet entered in
-# /etc/mtab because / was still mounted read-only:
+# Fix /etc/mtab to list sys, proc, and devtmpfs if they were not yet
+# entered in /etc/mtab because / was still mounted read-only:
if [ -d /proc/sys ]; then
/sbin/mount -f proc /proc -t proc